@@ -1,25 +1,25 @@
 package Email::Sender::Failure::Temporary;
-BEGIN {
-  $Email::Sender::Failure::Temporary::VERSION = '0.102370';
-}
-use Moose;
-extends 'Email::Sender::Failure';
 # ABSTRACT: a temporary delivery failure
+$Email::Sender::Failure::Temporary::VERSION = '1.300018';
+use Moo;
+extends 'Email::Sender::Failure';
 
-__PACKAGE__->meta->make_immutable(inline_constructor => 0);
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Failure::Temporary - a temporary delivery failure
 
 =head1 VERSION
 
-version 0.102370
+version 1.300018
 
 =head1 AUTHOR
 
@@ -27,10 +27,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
