@@ -1,29 +1,35 @@
 package Email::Sender::Role::HasMessage;
-BEGIN {
-  $Email::Sender::Role::HasMessage::VERSION = '0.102370';
-}
-use Moose::Role;
 # ABSTRACT: an object that has a message
+$Email::Sender::Role::HasMessage::VERSION = '1.300018';
+use Moo::Role;
 
+#pod =attr message
+#pod
+#pod This attribute is a message associated with the object.
+#pod
+#pod =cut
 
 has message => (
   is       => 'ro',
   required => 1,
 );
 
-no Moose::Role;
+no Moo::Role;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Role::HasMessage - an object that has a message
 
 =head1 VERSION
 
-version 0.102370
+version 1.300018
 
 =head1 ATTRIBUTES
 
@@ -37,10 +43,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
