@@ -1,11 +1,15 @@
 package Email::Sender::Simple;
-BEGIN {
-  $Email::Sender::Simple::VERSION = '0.102370';
-}
-use Moose;
-with 'Email::Sender::Role::CommonSending';
 # ABSTRACT: the simple interface for sending mail with Sender
+$Email::Sender::Simple::VERSION = '1.300018';
+use Moo;
+with 'Email::Sender::Role::CommonSending';
 
+#pod =head1 SEE INSTEAD
+#pod
+#pod For now, the best documentation of this class is in
+#pod L<Email::Sender::Manual::QuickStart>.
+#pod
+#pod =cut
 
 use Sub::Exporter::Util ();
 use Sub::Exporter -setup => {
@@ -17,6 +21,7 @@ use Sub::Exporter -setup => {
 
 use Email::Address;
 use Email::Sender::Transport;
+use Email::Sender::Util;
 use Try::Tiny;
 
 {
@@ -24,35 +29,39 @@ use Try::Tiny;
   my $DEFAULT_FROM_ENV;
 
   sub _default_was_from_env {
-    my ($self) = @_;
-    $self->default_transport;
+    my ($class) = @_;
+    $class->default_transport;
     return $DEFAULT_FROM_ENV;
   }
 
+  sub transport_from_env {
+    my ($class, $env_base) = @_;
+    $env_base ||= 'EMAIL_SENDER_TRANSPORT';
+
+    my $transport_class = $ENV{$env_base};
+    return unless defined $transport_class and length $transport_class;
+
+    my %arg;
+    for my $key (grep { /^\Q$env_base\E_[_0-9A-Za-z]+$/ } keys %ENV) {
+      (my $new_key = $key) =~ s/^\Q$env_base\E_//;
+      $arg{lc $new_key} = $ENV{$key};
+    }
+
+    return Email::Sender::Util->_easy_transport($transport_class, \%arg);
+  }
+
   sub default_transport {
     return $DEFAULT_TRANSPORT if $DEFAULT_TRANSPORT;
-    my ($self) = @_;
-    
-    if ($ENV{EMAIL_SENDER_TRANSPORT}) {
-      my $transport_class = $ENV{EMAIL_SENDER_TRANSPORT};
+    my ($class) = @_;
 
-      if ($transport_class !~ tr/://) {
-        $transport_class = "Email::Sender::Transport::$transport_class";
-      }
-
-      Class::MOP::load_class($transport_class);
-
-      my %arg;
-      for my $key (grep { /^EMAIL_SENDER_TRANSPORT_\w+/ } keys %ENV) {
-        (my $new_key = $key) =~ s/^EMAIL_SENDER_TRANSPORT_//;
-        $arg{lc $new_key} = $ENV{$key};
-      }
+    my $transport = $class->transport_from_env;
 
+    if ($transport) {
       $DEFAULT_FROM_ENV  = 1;
-      $DEFAULT_TRANSPORT = $transport_class->new(\%arg);
+      $DEFAULT_TRANSPORT = $transport;
     } else {
       $DEFAULT_FROM_ENV  = 0;
-      $DEFAULT_TRANSPORT = $self->build_default_transport;
+      $DEFAULT_TRANSPORT = $class->build_default_transport;
     }
 
     return $DEFAULT_TRANSPORT;
@@ -77,9 +86,9 @@ use Try::Tiny;
 # Maybe this should be an around, but I'm just not excited about figuring out
 # order at the moment.  It just has to work. -- rjbs, 2009-06-05
 around prepare_envelope => sub {
-  my ($orig, $self, $arg) = @_;
+  my ($orig, $class, $arg) = @_;
   $arg ||= {};
-  my $env = $self->$orig($arg);
+  my $env = $class->$orig($arg);
 
   $env = {
     %$arg,
@@ -90,19 +99,19 @@ around prepare_envelope => sub {
 };
 
 sub send_email {
-  my ($self, $email, $arg) = @_;
+  my ($class, $email, $arg) = @_;
 
-  my $transport = $self->default_transport;
+  my $transport = $class->default_transport;
 
   if ($arg->{transport}) {
     $arg = { %$arg }; # So we can delete transport without ill effects.
-    $transport = delete $arg->{transport} unless $self->_default_was_from_env;
+    $transport = delete $arg->{transport} unless $class->_default_was_from_env;
   }
 
-  confess("transport $transport not safe for use with Email::Sender::Simple")
+  Carp::confess("transport $transport not safe for use with Email::Sender::Simple")
     unless $transport->is_simple;
 
-  my ($to, $from) = $self->_get_to_from($email, $arg);
+  my ($to, $from) = $class->_get_to_from($email, $arg);
 
   Email::Sender::Failure::Permanent->throw("no recipients") if ! @$to;
   Email::Sender::Failure::Permanent->throw("no sender") if ! defined $from;
@@ -117,10 +126,10 @@ sub send_email {
 }
 
 sub try_to_send {
-  my ($self, $email, $arg) = @_;
+  my ($class, $email, $arg) = @_;
 
   try {
-    return $self->send($email, $arg);
+    return $class->send($email, $arg);
   } catch {
     my $error = $_ || 'unknown error';
     return if try { $error->isa('Email::Sender::Failure') };
@@ -129,7 +138,7 @@ sub try_to_send {
 }
 
 sub _get_to_from {
-  my ($self, $email, $arg) = @_;
+  my ($class, $email, $arg) = @_;
 
   my $to = $arg->{to};
   unless (@$to) {
@@ -155,19 +164,22 @@ sub _get_to_from {
   return ($to, $from);
 }
 
-no Moose;
+no Moo;
 "220 OK";
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Simple - the simple interface for sending mail with Sender
 
 =head1 VERSION
 
-version 0.102370
+version 1.300018
 
 =head1 SEE INSTEAD
 
@@ -180,10 +192,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
