@@ -1,25 +1,31 @@
 package Email::Sender::Success;
-BEGIN {
-  $Email::Sender::Success::VERSION = '0.102370';
-}
-use Moose;
 # ABSTRACT: the result of successfully sending mail
+$Email::Sender::Success::VERSION = '1.300018';
+use Moo;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod An Email::Sender::Success object is just an indicator that an email message was
+#pod successfully sent.  Unless extended, it has no properties of its own.
+#pod
+#pod =cut
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Success - the result of successfully sending mail
 
 =head1 VERSION
 
-version 0.102370
+version 1.300018
 
 =head1 DESCRIPTION
 
@@ -32,10 +38,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
