@@ -1,32 +1,43 @@
 package Email::Sender::Success::Partial;
-our $VERSION = '0.100460';
-use Moose;
-extends 'Email::Sender::Success';
 # ABSTRACT: a report of partial success when delivering
+$Email::Sender::Success::Partial::VERSION = '1.300018';
+use Moo;
+extends 'Email::Sender::Success';
 
+use MooX::Types::MooseLike::Base qw(InstanceOf);
+
+#pod =head1 DESCRIPTION
+#pod
+#pod These objects indicate that some deliver was accepted for some recipients and
+#pod not others.  The success object's C<failure> attribute will return a
+#pod L<Email::Sender::Failure::Multi> describing which parts of the delivery failed.
+#pod
+#pod =cut
 
 use Email::Sender::Failure::Multi;
 
 has failure => (
   is  => 'ro',
-  isa => 'Email::Sender::Failure::Multi',
+  isa => InstanceOf['Email::Sender::Failure::Multi'],
   required => 1,
 );
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Success::Partial - a report of partial success when delivering
 
 =head1 VERSION
 
-version 0.100460
+version 1.300018
 
 =head1 DESCRIPTION
 
@@ -36,14 +47,13 @@ L<Email::Sender::Failure::Multi> describing which parts of the delivery failed.
 
 =head1 AUTHOR
 
-  Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
