@@ -1,28 +1,34 @@
 package Email::Sender::Transport::DevNull;
-BEGIN {
-  $Email::Sender::Transport::DevNull::VERSION = '0.102370';
-}
-use Moose;
-with 'Email::Sender::Transport';
 # ABSTRACT: happily throw away your mail
+$Email::Sender::Transport::DevNull::VERSION = '1.300018';
+use Moo;
+with 'Email::Sender::Transport';
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This class implements L<Email::Sender::Transport>.  Any mail sent through a
+#pod DevNull transport will be silently discarded.
+#pod
+#pod =cut
 
 sub send_email { return $_[0]->success }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::DevNull - happily throw away your mail
 
 =head1 VERSION
 
-version 0.102370
+version 1.300018
 
 =head1 DESCRIPTION
 
@@ -35,10 +41,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
