@@ -1,17 +1,23 @@
 package Email::Sender::Transport::Print;
-BEGIN {
-  $Email::Sender::Transport::Print::VERSION = '0.102370';
-}
-use Moose;
-with 'Email::Sender::Transport';
 # ABSTRACT: print email to a filehandle (like stdout)
+$Email::Sender::Transport::Print::VERSION = '1.300018';
+use Moo;
+with 'Email::Sender::Transport';
 
+#pod =head1 DESCRIPTION
+#pod
+#pod When this transport is handed mail, it prints it to a filehandle.  By default,
+#pod it will print to STDOUT, but it can be given any L<IO::Handle> object to print
+#pod to as its C<fh> attribute.
+#pod
+#pod =cut
 
 use IO::Handle;
+use MooX::Types::MooseLike::Base qw(InstanceOf);
 
 has 'fh' => (
   is       => 'ro',
-  isa      => 'IO::Handle',
+  isa      => InstanceOf['IO::Handle'],
   required => 1,
   default  => sub { IO::Handle->new_from_fd(fileno(STDOUT), 'w') },
 );
@@ -32,20 +38,22 @@ sub send_email {
   return $self->success;
 }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::Print - print email to a filehandle (like stdout)
 
 =head1 VERSION
 
-version 0.102370
+version 1.300018
 
 =head1 DESCRIPTION
 
@@ -59,10 +67,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
